@@ -171,6 +171,16 @@ def pytest_addoption(parser):
                 for webdriver.""",
     )
 
+    parser.addoption(
+        "--lt",
+        "--lambdatest",
+        action="store_true",
+        dest="lambda_test",
+        default=False,
+        help="""The option to use Lambda test as a remote server
+                for webdriver.""",
+    )
+
     sys_argv = sys.argv
     ab_config._device_shortcut = None
 
@@ -236,6 +246,7 @@ def pytest_configure(config):
     ab_config.slow_mode = config.getoption("slow_mode")
     ab_config.reuse_session = config.getoption("reuse_session")
     ab_config.browser_stack = config.getoption("browser_stack")
+    ab_config.lambda_test= config.getoption("lambda_test")
     ab_config._is_timeout_changed = False
     ab_config._SMALL_TIMEOUT = settings.SMALL_TIMEOUT
     ab_config._LARGE_TIMEOUT = settings.LARGE_TIMEOUT
